# FAN-C: Framework for the ANalysis of C-like data

FAN-C provides a pipeline for analysing Hi-C data starting at mapped paired-end sequencing reads.

![](https://raw.githubusercontent.com/vaquerizaslab/fanc/main/docsrc/fnc-overview.png)

Please check out the documentation at https://vaquerizaslab.github.io/fanc for detailed installation and usage
instructions!